@@ -142,7 +142,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -158,14 +158,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_lambda
-import aws_cdk.aws_secretsmanager
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_secretsmanager as _aws_cdk_aws_secretsmanager_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class LambdaToSecretsmanager(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-secretsmanager.LambdaToSecretsmanager",
 ):
@@ -175,18 +175,18 @@ class LambdaToSecretsmanager(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_secret_obj: typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.Secret] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         grant_write_access: typing.Optional[builtins.str] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         secret_environment_variable_name: typing.Optional[builtins.str] = None,
-        secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        secret_props: typing.Optional[typing.Union[_aws_cdk_aws_secretsmanager_ceddda9d.SecretProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -205,22 +205,7 @@ class LambdaToSecretsmanager(
         :summary: Constructs a new instance of the LambdaToSecretsmanager class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                grant_write_access: typing.Optional[builtins.str] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                secret_environment_variable_name: typing.Optional[builtins.str] = None,
-                secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__444fb83809c5da8f4e91f86156cafd25a7ec722f3c37e439ea9d205271b23b12)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToSecretsmanagerProps(
@@ -239,18 +224,18 @@ class LambdaToSecretsmanager(
 
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
-    def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
+    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="secret")
-    def secret(self) -> aws_cdk.aws_secretsmanager.Secret:
-        return typing.cast(aws_cdk.aws_secretsmanager.Secret, jsii.get(self, "secret"))
+    def secret(self) -> _aws_cdk_aws_secretsmanager_ceddda9d.Secret:
+        return typing.cast(_aws_cdk_aws_secretsmanager_ceddda9d.Secret, jsii.get(self, "secret"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], jsii.get(self, "vpc"))
 
 
 @jsii.data_type(
@@ -273,14 +258,14 @@ class LambdaToSecretsmanagerProps:
         self,
         *,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_secret_obj: typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.Secret] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         grant_write_access: typing.Optional[builtins.str] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
         secret_environment_variable_name: typing.Optional[builtins.str] = None,
-        secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        secret_props: typing.Optional[typing.Union[_aws_cdk_aws_secretsmanager_ceddda9d.SecretProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
@@ -296,26 +281,13 @@ class LambdaToSecretsmanagerProps:
         :summary: The properties for the LambdaToSecretsmanager class.
         '''
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
         if isinstance(secret_props, dict):
-            secret_props = aws_cdk.aws_secretsmanager.SecretProps(**secret_props)
+            secret_props = _aws_cdk_aws_secretsmanager_ceddda9d.SecretProps(**secret_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_secret_obj: typing.Optional[aws_cdk.aws_secretsmanager.Secret] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                grant_write_access: typing.Optional[builtins.str] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                secret_environment_variable_name: typing.Optional[builtins.str] = None,
-                secret_props: typing.Optional[typing.Union[aws_cdk.aws_secretsmanager.SecretProps, typing.Dict[str, typing.Any]]] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__df69763c9616cce5c96cc24ad89f9f2342ec78081d7504421770c379d70520d0)
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
             check_type(argname="argument existing_secret_obj", value=existing_secret_obj, expected_type=type_hints["existing_secret_obj"])
@@ -325,7 +297,7 @@ class LambdaToSecretsmanagerProps:
             check_type(argname="argument secret_environment_variable_name", value=secret_environment_variable_name, expected_type=type_hints["secret_environment_variable_name"])
             check_type(argname="argument secret_props", value=secret_props, expected_type=type_hints["secret_props"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if deploy_vpc is not None:
             self._values["deploy_vpc"] = deploy_vpc
         if existing_lambda_obj is not None:
@@ -355,28 +327,32 @@ class LambdaToSecretsmanagerProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    def existing_lambda_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
-    def existing_secret_obj(self) -> typing.Optional[aws_cdk.aws_secretsmanager.Secret]:
+    def existing_secret_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.Secret]:
         '''Existing instance of Secret object, providing both this and secretProps will cause an error.
 
         :default: - Default props are used
         '''
         result = self._values.get("existing_secret_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.Secret], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.Secret], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC for the construct to use (construct will NOT create a new VPC in this case).'''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def grant_write_access(self) -> typing.Optional[builtins.str]:
@@ -392,13 +368,13 @@ class LambdaToSecretsmanagerProps:
     @builtins.property
     def lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''User provided props to override the default props for the Lambda function.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
     def secret_environment_variable_name(self) -> typing.Optional[builtins.str]:
@@ -410,19 +386,21 @@ class LambdaToSecretsmanagerProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def secret_props(self) -> typing.Optional[aws_cdk.aws_secretsmanager.SecretProps]:
+    def secret_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.SecretProps]:
         '''Optional user-provided props to override the default props for the Secret.
 
         :default: - Default props are used
         '''
         result = self._values.get("secret_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_secretsmanager.SecretProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.SecretProps], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Properties to override default properties if deployVpc is true.'''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -442,3 +420,35 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__444fb83809c5da8f4e91f86156cafd25a7ec722f3c37e439ea9d205271b23b12(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_secret_obj: typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.Secret] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    grant_write_access: typing.Optional[builtins.str] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    secret_environment_variable_name: typing.Optional[builtins.str] = None,
+    secret_props: typing.Optional[typing.Union[_aws_cdk_aws_secretsmanager_ceddda9d.SecretProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__df69763c9616cce5c96cc24ad89f9f2342ec78081d7504421770c379d70520d0(
+    *,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_secret_obj: typing.Optional[_aws_cdk_aws_secretsmanager_ceddda9d.Secret] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    grant_write_access: typing.Optional[builtins.str] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    secret_environment_variable_name: typing.Optional[builtins.str] = None,
+    secret_props: typing.Optional[typing.Union[_aws_cdk_aws_secretsmanager_ceddda9d.SecretProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
